"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var composition_api_1 = require("@vue/composition-api");
function useFullscreen(elRef) {
    var isFullscreen = composition_api_1.ref(false);
    var handleFullscreenChange = function () {
        if (!isFullscreen.value)
            return;
        var isCurrentlyFullscreen = !!document.fullscreenElement;
        isFullscreen.value = isCurrentlyFullscreen;
    };
    var startTracking = function () {
        document.addEventListener('fullscreenchange', handleFullscreenChange);
    };
    var stopTracking = function () {
        document.removeEventListener('fullscreenchange', handleFullscreenChange);
    };
    var start = function () {
        if (!elRef.value)
            return;
        if (isFullscreen.value)
            return;
        elRef.value.requestFullscreen().then(function () {
            isFullscreen.value = true;
            startTracking();
        });
    };
    var stop = function () {
        if (!isFullscreen.value)
            return;
        document.exitFullscreen().then(function () {
            isFullscreen.value = false;
            stopTracking();
        });
    };
    composition_api_1.onUnmounted(stopTracking);
    return { isFullscreen: isFullscreen, start: start, stop: stop };
}
exports.useFullscreen = useFullscreen;
