"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var composition_api_1 = require("@vue/composition-api");
function useMediaDevices(runOnMount) {
    if (runOnMount === void 0) { runOnMount = true; }
    var devicesState = composition_api_1.ref([]);
    var isTracking = composition_api_1.ref(false);
    var isTracked = composition_api_1.ref(false);
    var deviceMap = function (_a) {
        var deviceId = _a.deviceId, groupId = _a.groupId, kind = _a.kind, label = _a.label;
        return ({
            deviceId: deviceId,
            groupId: groupId,
            kind: kind,
            label: label
        });
    };
    var handleDeviceChange = function () {
        navigator.mediaDevices
            .enumerateDevices()
            .then(function (deviceList) {
            if (!isTracking.value)
                return;
            isTracked.value = true;
            devicesState.value = deviceList.map(deviceMap);
        })
            .catch(function () {
            isTracked.value = false;
        });
    };
    var start = function () {
        if (isTracking.value)
            return;
        handleDeviceChange();
        navigator.mediaDevices.addEventListener('devicechange', handleDeviceChange);
        isTracking.value = true;
    };
    var stop = function () {
        if (!isTracking.value)
            return;
        navigator.mediaDevices.removeEventListener('devicechange', handleDeviceChange);
        isTracking.value = false;
    };
    composition_api_1.onMounted(function () { return runOnMount && start(); });
    composition_api_1.onUnmounted(stop);
    return { devicesState: devicesState, isTracking: isTracking, isTracked: isTracked, start: start, stop: stop };
}
exports.useMediaDevices = useMediaDevices;
